@@ -6,30 +6,19 @@ import json
 import os
 import sys
 # ----- port here. 5000 is flask; is moved to 8000 by gunicorn; to 80 by nginx
-CONFIG={'x':640,
-        'y':480 ,
-        'interpolation':'None',
-        'mintime':0.1,       # normal picture rate
-        'videodev':0,
-        'filename':'~/.config/test/cfg.json',
-        'user':'aaa',
-        'password':'aaa',
-        'port':5000,
-        'change':None,
-        'autoiris':True,
-        'riris':1000,
-        'pantilt':False,
-        'pan':0,
-        'tilt':0,
-        'gamma_adjust':False,
-        'rgain':0,
-        'use_v4l':True,      # zdenek84 had a problem with. I try again
-        'quit':False         # this is howto quit
+CONFIG={'filename':'~/.config/codeframe/cfg.json',
+        'history':'~/.config/codeframe/history',
+        'quit':False         #
 }
 
-#CFG_DEBUG = True
-#CFG_DEBUG = False
+#================================== all global variables are recommended to store here
+global_variables_here = None
 
+#================================== all global variables are recommended to store here
+
+#CFG_DEBUG = True
+CFG_DEBUG = False
+myPromptSession = None
 
 #===========================================================
 #===========================================================
@@ -48,17 +37,16 @@ def verify_config(filename = ""):
             with open(os.path.expanduser(cfg), "r") as f:
                 dicti = json.load(f)
         ok = True
-        #if CFG_DEBUG:print("D... config verified")
+        if CFG_DEBUG:print("D... config verified")
     except:
-        #if CFG_DEBUG:
-        print("D... verification config FAILED")
+        if CFG_DEBUG:
+            print("D... verification config FAILED")
     return ok
 
 def get_config_file():
     ''' returns the filename where config is stored'''
     global CONFIG
     return CONFIG['filename']
-
 def show_config( cdict=None , filename = ""):
     '''used inside, shows current config dictionary OR other dict'''
     global CONFIG
@@ -76,6 +64,7 @@ def cfg_to_bak(filenamebk="", filename = ""):
     if filename != "":
         CONFIG['filename'] = filename
 
+    cfg = None
     if filenamebk=="":
         cfg = CONFIG['filename']
     else:
@@ -84,8 +73,8 @@ def cfg_to_bak(filenamebk="", filename = ""):
     cfgbak = cfg + ".bak"
     #print("D... cfg:",cfg)
     #print("D... cfgbak:",cfgbak)
-    #if CFG_DEBUG:
-    print("D... creating a backup config:", cfgbak )
+    if CFG_DEBUG:
+        print("D... creating a backup config:", cfgbak )
     if not os.path.isfile( os.path.expanduser(cfg)):
         print(f"X... config {cfg} doesnt exist (yet?, OK)")
         return True
@@ -113,17 +102,17 @@ def bak_to_cfg(filenamebk="", filename = ""):
         cfg = filenamebk
 
     cfgbak = cfg + ".bak"
-    #if CFG_DEBUG:
-    print("D... testing if backup config exists:", cfgbak)
+    if CFG_DEBUG:
+        print("D... testing if backup config exists:", cfgbak)
     if os.path.isfile( os.path.expanduser(cfgbak)):
-        #if CFG_DEBUG:
-        print("D... BACUP config exists:",cfgbak, "... renaming to:", cfg)
+        if CFG_DEBUG:
+            print("D... BACUP config exists:",cfgbak, "... renaming to:", cfg)
         os.rename(os.path.expanduser(cfgbak),
                   os.path.expanduser(cfg))
-        #if CFG_DEBUG:print("D... config is recovered from:", cfgbak)
+        if CFG_DEBUG:print("D... config is recovered from:", cfgbak)
     else:
-        #if CFG_DEBUG:
-        print("D... bak config did not exist:", cfgbak,"no bak file recovery")
+        if CFG_DEBUG:
+            print("D... bak config did not exist:", cfgbak,"no bak file recovery")
 
 
 def save_config(filenamesv="", filename = ""): # duplicit... filename overrides
@@ -137,27 +126,27 @@ def save_config(filenamesv="", filename = ""): # duplicit... filename overrides
     else:
         cfg = filenamesv
 
-    print("D... calling cfg_to_bak:", cfg)
+    if CFG_DEBUG: print("D... calling cfg_to_bak:", cfg)
     if not cfg_to_bak(cfg):
         sys.exit(1)
 
-    print("D... writing config:", cfg)
+    if CFG_DEBUG: print("D... writing config:", cfg)
 
     ### rozxxx
     dir2create = os.path.dirname( cfg )
     #print("D...",dir2create)
     if not os.path.isdir( os.path.expanduser(dir2create )):
-        print(f"D... trying to create directory {dir2create} if needed")
+        if CFG_DEBUG: print(f"D... trying to create directory {dir2create} if needed")
         result = False
         os.mkdir( os.path.expanduser(dir2create ))
 
     with open(os.path.expanduser(cfg), "w+") as f:
         f.write(json.dumps(CONFIG, indent=1))
-        #if CFG_DEBUG:print("D... config was written:", cfg)
+        if CFG_DEBUG:print("D... config was written:", cfg)
 
     if verify_config(filename):
-        #if CFG_DEBUG:
-        print("D... verified by verify_config ... ok ... ending here")
+        if CFG_DEBUG:
+            print("D... verified by verify_config ... ok ... ending here")
         return True
     #====ELSE RECOVER BAK
     return bak_to_cfg()
@@ -171,34 +160,34 @@ def load_config(filename=""):
         CONFIG['filename'] = filename
     cfg = CONFIG['filename']
     cfg = cfg+".from_memory"
-    #if CFG_DEBUG:
-    print("D... calling save_config:")
+    if CFG_DEBUG:
+        print("D... calling save_config:")
     save_config( cfg )
 
     cfg = CONFIG['filename']
-    #if CFG_DEBUG:print("D... loading config from",cfg)
+    if CFG_DEBUG:print("D... loading config from",cfg)
 
     if not verify_config(filename):
         print("X... FAILED on verifications")
         return False
 
-    #if CFG_DEBUG:
-    print("D... passed verification of:",cfg)
+    if CFG_DEBUG:
+        print("D... passed verification of:",cfg)
     dicti = CONFIG
 
-    #if CFG_DEBUG:
-    print("D... directly loading json:",cfg)
+    if CFG_DEBUG:
+        print("D... directly loading json:",cfg)
     if os.path.isfile( os.path.expanduser(cfg)):
         with open(os.path.expanduser(cfg), "r") as f:
             dicti = json.load(f)
 
     # rewriting in memory
     if sorted(dicti.keys()) == sorted(CONFIG.keys()):
-        #if CFG_DEBUG:
-        print("D... memory and disk identical:")
+        if CFG_DEBUG:
+            print("D... memory and disk identical:")
     else:
-        #if CFG_DEBUG:
-        print("X... memory and disk differ:")
+        if CFG_DEBUG:
+            print("X... memory and disk differ:")
         # show_config(CONFIG)
         # there may be more lines in the CODE after upgrade.
         for k in CONFIG.keys(): # search CODE version
@@ -208,11 +197,11 @@ def load_config(filename=""):
 
 
     CONFIG = dicti
-    #if CFG_DEBUG:
-    print("D... final CONFIG:")
+    if CFG_DEBUG:
+        print("D... final CONFIG:")
     #show_config(filename)
-    #if CFG_DEBUG:
-    print("D... end load")
+    if CFG_DEBUG:
+        print("D... end load")
 
 
 def loadsave(filename = ""):
